@@ -1,16 +1,25 @@
 /* This is an auxiliary test program for rc.  */
 
+#include "config.h"
+
 #include <fcntl.h>
 #include <stdio.h>
+#include <stdlib.h>
+#include <sys/types.h>
+#include <unistd.h>
 
-void out0(void) {
+static void out0(void) {
 	putchar('t'); putchar('r');
 	putchar('\0');
 	putchar('u'); putchar('e');
 	putchar('\n');
 }
 
-void makenonblock(void) {
+static void ctrl_a(void) {
+	puts("a\001ab\002b");
+}
+
+static void makenonblock(void) {
 	int flags;
 
 	if ((flags = fcntl(0, F_GETFL)) == -1)
@@ -25,6 +34,9 @@ int main(int argc, char **argv) {
 	case '0':
 		out0();
 		break;
+	case 'a':
+		ctrl_a();
+		break;
 	case 'n':
 		makenonblock();
 		break;
